slepc-3.18.0 2022-10-01
Report Typos and Errors

# EPSCISSSetSizes

Sets the values of various size parameters in the CISS solver.

### Synopsis

    #include "slepceps.h"
    PetscErrorCode EPSCISSSetSizes(EPS eps,PetscInt ip,PetscInt bs,PetscInt ms,PetscInt npart,PetscInt bsmax,PetscBool realmats)

Logically Collective on eps

### Input Parameters

| eps | - the eigenproblem solver context
| ip | - number of integration points
| bs | - block size
| ms | - moment size
| npart | - number of partitions when splitting the communicator
| bsmax | - max block size
| realmats | - A and B are real

### Options Database Keys

| -eps_ciss_integration_points | - Sets the number of integration points
| -eps_ciss_blocksize | - Sets the block size
| -eps_ciss_moments | - Sets the moment size
| -eps_ciss_partitions | - Sets the number of partitions
| -eps_ciss_maxblocksize | - Sets the maximum block size
| -eps_ciss_realmats | - A and B are real

### Note

The default number of partitions is 1. This means the internal KSP object is shared among all processes of the EPS communicator. Otherwise, the communicator is split into npart communicators, so that npart KSP solves proceed simultaneously.

### See Also

EPSCISSGetSizes()

### Level

advanced

### Location

src/eps/impls/ciss/ciss.c
Index of all EPS routines
Table of Contents for all manual pages
Index of all manual pages